package websocket

import (
	"encoding/json"
	"github.com/charmbracelet/log"

	"git.smsvc.net/pomodoro/GoTomato/internal/pomodoro"
	"git.smsvc.net/pomodoro/GoTomato/internal/shared"
	"git.smsvc.net/pomodoro/GoTomato/pkg/models"
)

// Listens for commands from a client and handles them
func handleClientCommands(c models.Client) {
	ws := c.Conn
	for {
		var clientCommand models.ClientCommand

		_, message, err := ws.ReadMessage()
		if err != nil {
			log.Info("Client disconnected:", "msg", err, "host", ws.NetConn().RemoteAddr(), "clients", len(Clients)-1)
			delete(Clients, ws)
			break
		}

		// Handle incoming commands
		err = json.Unmarshal(message, &clientCommand)
		if err != nil {
			log.Error("Error unmarshalling command:", "msg", err)
			continue
		}

		// Process the command if pomodoro password matches
		if clientCommand.Password == shared.PomodoroPassword {
			switch clientCommand.Command {
			case "start":
				if !pomodoro.IsPomodoroOngoing() {
					go pomodoro.RunPomodoro() // Start the timer with the list of clients
				}
			case "stop":
				if pomodoro.IsPomodoroOngoing() {
					pomodoro.ResetPomodoro() // Reset Pomodoro
				}
			case "pause":
				if pomodoro.IsPomodoroOngoing() && !pomodoro.IsPomodoroPaused() {
					pomodoro.PausePomodoro() // Pause the timer
				}
			case "resume":
				if pomodoro.IsPomodoroOngoing() && pomodoro.IsPomodoroPaused() {
					pomodoro.ResumePomodoro() // Resume the timer
				}
			case "updateSettings":
				if !pomodoro.IsPomodoroOngoing() {
					pomodoro.UpdateSettings(clientCommand.Settings)
				}
			}
		}

	}
}
